%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\
% Initial File for Direct Torque Control of an Induction Motor   %\
% 					                                             %\
% Title   : Init_IM                                          	 %\
% Author  : Buchholz, Oleg					                     %\
% Date    : 2012-06-28                                 			 %\
%                                                            	 %\
% Uni Paderborn                                                  %\
% Fachgebiet LEA   					                             %\
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%\

clear all; close all; clc;

%% Selection of the task

task = 2;         % type in which task you want to work on
% selection choices: 1,2

%%%%%%%%%%%% Motor parameters
U_N = 400;                          % rated voltage [V]
f_N = 50;                           % rated electrical frequency [Hz]
T_N = 30;                           % rated Torque [Nm]
J = 0.02;                           % inertia [kgm^2]
p = 2.0;                            % number of pole pairs  
L_m = 116.012e-3;                   % main inductivity [H]                          
L_ss = 6.24e-3;                     % stator leakage inductance [H]                         
L_sr = 6.24e-3;                     % rotor leakage inductance [H]

L_s = L_m+L_ss;                     % stator inductance [H]			 
L_r = L_s;                          % rotor inductance [H]	
                           	 			 
R_r = 0.916;                        % rotor resistance [Ohm]			 
R_s = 1.154;                        % stator resistance [Ohm]

tau_r = L_r/R_r;                    % rotor time constant [s]
tau_s = L_s/R_s;                    % stator time constant [s]

sigma=1.-L_m*L_m/L_s/L_r;           % leakage number 
rho=1+L_m*L_m/L_s/L_s*R_r/R_s;      % resistance number
 
U_DC = 600 ;                        % DC link Voltage [V]

n_N = f_N*60/p;                     % mechanical rated speed [1/min]
psi_s_N = U_N*sqrt(2/3)/(2*pi*f_N); % rated stator flux [Vs]	  

switch task
	case 1
    %--- task 1 motor model of the IM
    T_sim		= 1;          % simulation time [s]
    t_step      = 0.5;         % load torquestep time [s]
    
	T_L_start   = 0;	        % load torque for T_sim = 0 s
	T_L_end     = T_N;          % load torque for T_sim = 0.25 s
        
    flag.mux_omega = 1;	        % speed results from the torque (free running motor)
	n_const     = 0;            % constant speed [1/min]
    
    open('.\Motor_model_IM.mdl')
    msgbox(['Initialisation for task ', num2str(task), ' is done!']);
	case 2
    %--- task 2 Direct Torque Control of the Induction Motor

    T_sim     = 0.5;            % simulation time [s]
    t_step = 0.25;              % Step time for Torque reference [s]
   
    psi_s_ref =  psi_s_N;       % reference stator flux [Vs]
    T_ref_start = 0.1*T_N;      % reference torquet T_sim = 0 s [Nm] 
    T_ref_end = 0.9*T_N;        % reference torque T_sim = 0.25 s [Nm] 
	
    flag.mux_omega = 0;	        % constant speed (braked motor)
    n_const = 0.5*n_N;          % constant speed [1/min]
    
    % hysteresis band limits for flux and torque
    delta_psi = 0.02*psi_s_N;   % Switch on point / Switch off point for Relay
    delta_T = 0.1*T_N;          % Switch on point / Switch off point for Relay
				
    open('.\DTC_IM.mdl')
    msgbox(['Initialisation for task ', num2str(task), ' is done!']);
    
	otherwise 
    msgbox('No valid task selected! You can select between 1 and 2!');
end 